==> qtjambi-qt3drender-6.2.1-sources.jar: io/qt/qt3d/render/QLayer.java <==
package io.qt.qt3d.render;


/**
 * <p>Way of filtering which entities will be rendered</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qlayer.html">Qt3DRender::QLayer</a></p>
 */
public class QLayer extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLayer.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlayer.html#recursive-prop">Qt3DRender::QLayer::recursiveChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="recursive")
    public final Signal0 recursiveChanged = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QLayer(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLayer() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlayer.html#QLayer">Qt3DRender::QLayer::QLayer(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLayer(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLayer instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlayer.html#recursive-prop">Qt3DRender::QLayer::recursive()const</a></p>
     */
    @io.qt.QtPropertyReader(name="recursive")
    @io.qt.QtUninvokable
    public final boolean recursive(){
        return recursive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean recursive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlayer.html#recursive-prop">Qt3DRender::QLayer::setRecursive(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="recursive")
    @io.qt.QtUninvokable
    public final void setRecursive(boolean recursive){
        setRecursive_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), recursive);
    }
    
    @io.qt.QtUninvokable
    private native void setRecursive_native_bool(long __this__nativeId, boolean recursive);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLayer(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLayer(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLayer instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.9-sources.jar: io/qt/qt3d/render/QLayer.java <==
package io.qt.qt3d.render;


/**
 * <p>Way of filtering which entities will be rendered</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qlayer.html">Qt3DRender::QLayer</a></p>
 */
public class QLayer extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLayer.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlayer.html#recursive-prop">Qt3DRender::QLayer::recursiveChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="recursive")
    public final Signal0 recursiveChanged = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QLayer(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLayer() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlayer.html#QLayer">Qt3DRender::QLayer::QLayer(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLayer(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLayer instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlayer.html#recursive-prop">Qt3DRender::QLayer::recursive()const</a></p>
     */
    @io.qt.QtPropertyReader(name="recursive")
    @io.qt.QtUninvokable
    public final boolean recursive(){
        return recursive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean recursive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlayer.html#recursive-prop">Qt3DRender::QLayer::setRecursive(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="recursive")
    @io.qt.QtUninvokable
    public final void setRecursive(boolean recursive){
        setRecursive_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), recursive);
    }
    
    @io.qt.QtUninvokable
    private native void setRecursive_native_bool(long __this__nativeId, boolean recursive);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLayer(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLayer(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLayer instance, QDeclarativeConstructor constructor);
    
}
